#!/bin/sh
#
# xymon        Xymon network monitor
#
# chkconfig:   - 80 20
# description: Xymon is a network monitoring tool that can monitor hosts \
#              and services and shows monitor status via a webpage.

### BEGIN INIT INFO
# Provides: xymon
# Required-Start: $local_fs $network
# Required-Stop: $local_fs $network
# Short-Description: start and stop xymon
# Description: Xymon is a network monitoring tool that can monitor hosts
#              and services and shows monitor status via a webpage.
### END INIT INFO

# Source function library.
. /etc/rc.d/init.d/functions

prog="xymon"
user="$prog"
exec="/usr/lib/$prog/server/bin/xymonlaunch"
config="/usr/lib/$prog/server/etc/tasks.cfg"
env="/usr/lib/$prog/server/etc/xymonserver.cfg"
log="/var/log/$prog/xymonlaunch.log"
pid="/var/log/$prog/xymonlaunch.pid"
lockfile="/var/lock/subsys/$prog"

[ -f /etc/sysconfig/$prog ] && . /etc/sysconfig/$prog

LIST=($XYMONSERVERS)
if [ ${#LIST[*]} -eq 0 ]; then
	XYMONSERVERS=`grep XYMONSERVERIP= /etc/xymon/xymonserver.cfg | cut -d"\"" -f2`
	echo "XYMSRV=\"$XYMONSERVERS\""     >/var/run/xymonclient-runtime.cfg
	echo 'XYMSERVERS=""'                >>/var/run/xymonclient-runtime.cfg
elif [ ${#LIST[*]} -eq 1 ]; then
	echo "XYMSRV=\"$XYMONSERVERS\""     >/var/run/xymonclient-runtime.cfg
	echo 'XYMSERVERS=""'                >>/var/run/xymonclient-runtime.cfg
else
	echo 'XYMSRV="0.0.0.0"'             >/var/run/xymonclient-runtime.cfg
	echo "XYMSERVERS=\"$XYMONSERVERS\"" >>/var/run/xymonclient-runtime.cfg
fi

start() {
    [ -x $exec ] || exit 5
    echo -n $"Starting $prog: "
    daemon --user=$user "$exec --config=$config --env=$env --log=$log --pidfile=$pid"
    retval=$?
    echo
    [ $retval -eq 0 ] && touch $lockfile
    return $retval
}

stop() {
    echo -n $"Stopping $prog: "
    killproc -p $pid $prog
    retval=$?
    echo
    [ $retval -eq 0 ] && rm -f $lockfile
    return $retval
}

restart() {
    stop
    start
}

reload() {
    echo -n $"Reloading $prog configuration files: "
    killproc -p /var/log/$prog/xymond.pid $prog -HUP
    retval=$?
    echo
    [ $retval -eq 0 ] && touch $lockfile
    return $retval
}

rotate() {
    echo -n $"Rotating $prog logs: "
    killproc -p $pid $prog -HUP
    retval=$?
    echo
    return $retval
}

rh_status() {
    status -p $pid $prog
}

rh_status_q() {
    rh_status &>/dev/null
}


case "$1" in
    start)
        rh_status_q && exit 0
        $1
        ;;
    stop)
        rh_status_q || exit 0
        $1
        ;;
    restart|force-reload)
        restart
        ;;
    reload)
        rh_status_q || exit 7
        $1
        ;;
    status)
        rh_status
        ;;
    condrestart|try-restart)
        rh_status_q || exit 0
        restart
        ;;
    rotate)
        $1
        ;;
    *)
        echo $"Usage: $0 {start|stop|status|restart|condrestart|try-restart|reload|force-reload|rotate}"
        exit 2
esac
exit $?
